;;;--------------------------------------------------------------------;
;;;  First step is to load ActiveX functionality.  If ActiveX support  ;
;;;  already exists in document (can occur when Bonus tools have been  ;
;;;  loaded into AutoCAD), nothing happens. 
;;;--------------------------------------------------------------------;
  (vl-load-com)
  ; Aktives Element in globaler Variable abspeichern fr ActiveX
  (setq *aktzeichnung*
        	 (vla-get-ActiveDocument (vlax-get-acad-object))
  )
  ; Modellbereichsobjekt in globaler Variable abspeichern fr ActiveX
  (setq *ModelSpace*
       (vla-get-ModelSpace *aktzeichnung* ) ;_ end of vla-get-ModelSpace
  )



;; ##########################################################################################
;;   get_attributlist    								    ;
;;     liefert vom bergebenen Blockobjekt eine liste aller Attribute und deren Werte       ;
;;                                                                                          ;
;;   Parameter:  vla_obj  => Block als Vla-Objekt   				    :
;;                                                                                          ;
;;   Returnwert  Liste der Form: ( (att-tag1 . att-str1) (att-tag2 . att-str2) ...)                ;
;; ##########################################################################################
(defun get_attributlist (vla_obj / retlist index attobj  lattrib )
  ; Attributsliste des Blocks holen
  (setq lattrib (vlax-safearray->list (vlax-variant-value (vla-GetAttributes vla_obj))))
  ; Attributs-Liste erstellen
  (setq retlist '())
  (setq index 0) 
  (while (< index (length lattrib))
       (setq attobj (nth index lattrib))
       (setq retlist (append retlist (list (cons (vla-get-tagstring attobj) (vla-get-textstring attobj)))))
       (setq index (1+ index))
  ); ende while alle Attribute des SSM-Objektes durchlaufen
  (setq retlist retlist)
)

(defun SHS_plt( / aus block format anz pos attlis attkl mstb ben1 fh bstr bflag attribsToCheck)
  (setvar "cmddia" 0)
  (setvar "cmdecho" 0)
  (setvar "filedia" 0)
  (setvar "expert" 5)
  ; Blcke lschen
  (command "_purge" "BL" "*" "N")
  ; Format-Block suchen
  (setq aus (ssget "X" '((0 . "INSERT") (2 . "SHS_A*"))))
  (setq block (cdr (assoc 2 (entget (ssname aus 0)))))
    
  (cond
    ((= block "SHS_A0")
    (command "_plot" "J" "Modell" "" "A3" "Millimeter" "Q" "N" "Limiten" "Anpassen" "0.00,0.00" "J" "verkleinerung1.ctb" "J" "N" "N" "J" "J"))
    ((= block "SHS_A1")
    (command "_plot" "J" "Modell" "" "A3" "Millimeter" "Q" "N" "Limiten" "Anpassen" "0.00,0.00" "J" "verkleinerung1.ctb" "J" "N" "N" "J" "J"))
    ((= block "SHS_A2")
    (command "_plot" "J" "Modell" "" "A3" "Millimeter" "Q" "N" "Limiten" "Anpassen" "0.00,0.00" "J" "verkleinerung1.ctb" "J" "N" "N" "J" "J"))
    ((= block "SHS_A3")
    (command "_plot" "J" "Modell" "" "A3" "Millimeter" "Q" "N" "Limiten" "Anpassen" "0.00,0.00" "J" "monochrome.ctb" "J" "N" "N" "J" "J"))
    ((= block "SHS_A4")
    (command "_plot" "J" "Modell" "" "A4" "Millimeter" "H" "N" "Limiten" "Anpassen" "0.00,0.00" "J" "monochrome.ctb" "J" "N" "N" "J" "J"))
  )
  (setvar "cmddia" 1)
  (setvar "cmdecho" 1)
  (setvar "filedia" 1)
  (setvar "expert" 1)
)
 
;;##########################################################################################
;;   update_attribut 								    ;
;;     passt die Attribute des bergebenen SSM-Blockes entsprechend der mitgelieferten      ;
;;     Attributsliste                                                                       ;
;;                                                                                          ;
;;   Parameter:  vla_obj  => Block als Vla-Objekt   				    :
;;               attliste => Liste aller zu ndernder Attributsdatenpaare des SSM-Macros    ;
;;                            - ( (att-tag1 att-str1) (att-tag2 att-str2) ...)                ;
;; ##########################################################################################
(defun update_attribut (vla_obj attliste / item index attobj strtag strvalue lattrib )
  ; Attributsliste des SSM-Macro-Blocks holen
  (setq lattrib (vlax-safearray->list (vlax-variant-value (vla-GetAttributes vla_obj))))
  ; Liste aller zu ndernder Attributsdaten durchlaufen
  (foreach item attliste
    ; entsprechendes Attributs-objekt suchen
    (setq index 0) 
    (while (< index (length lattrib))
       (setq attobj (nth index lattrib))
       ; entspricht es dem aktuell zu ndernden Attribut?
       (if (= (car item) (vla-get-tagstring attobj))
	 (progn
	   ; neuen Attributswert setzen
	   (vla-put-textstring attobj (cadr item))
           (setq ssmcmd nil)
	   (setq index (length lattrib)) ; Schleife beenden
	 )  
       )
       (setq index (1+ index))
    ); ende while alle Attribute des SSM-Objektes durchlaufen 
  ); ende alle Attributsdatenpaare durchlaufen  
)
;####################################################################################
;;   checkEmptyAttribs   							    ;
;;     berprft jeden Attributsinhalt der bergebenen Tagliste, falls das Attribut ;
;;     nicht gesetzt ist, so wird ein Punkt als Attributsinhalt gesetzt.            ;
;;                                                                                  ;
;;   Parameter:  vla_obj  	=> Block als Vla-Objekt   			    :
;;               attribsToCheck => Liste aller zu berprfender Attributesnamen(Tags);
;;				   (list "Tag1" "Tag2" "Tag3" .....)                ;
;####################################################################################
(defun checkEmptyAttribs(blockobj attribsToCheck / len i sAttribTag)
  (setq len (length attribsToCheck))
  (setq i 0)
  (while ( < i len)
	(setq sAttribTag (nth i attribsToCheck))
	(if (not (get_attribut_value blockobj sAttribTag))
	    (update_attribut blockobj (list (list sAttribTag ".")))
	);if
	(setq i (1+ i))
   );while
)
;####################################################################################
;;   get_attribut_value 							    ;
;;     Gibt den Attributwert der gesuchten Attributsbezeichnung (Tag) zurck.       ;
;;     Fhrende Leerzeichen der Attributswerte werden nicht zurckgegeben.          ;
;;     Falls der Attributswert nur aus Leerzeichen besteht, oder nicht gesetzt ist, ;
;;     so wird nil zurckgegeben.                                                   ;
;;                                                                                  ;
;;   Parameter:  vla_obj  => Block als Vla-Objekt   				    :
;;               sTagName => Name der Attributsbezeichnung                          ;
;####################################################################################
(defun get_attribut_value (vla_obj sTagName / index attobj strvalue lattrib )
  ; Attributsliste des SSM-Macro-Blocks holen
  (setq lattrib (vlax-safearray->list (vlax-variant-value (vla-GetAttributes vla_obj))))
  ; Liste Attributsdaten durchlaufen
  
    ;Attributs-objekt suchen
    (setq index 0) 
    (while (< index (length lattrib))
       (setq attobj (nth index lattrib))
       ; entspricht es dem aktuell zu ndernden Attribut?
       (if (= sTagName (vla-get-tagstring attobj))
	 (progn
	   ;Attributswert holen
	   (setq strvalue (vla-get-textstring attobj))
	   ;Alle fhrenden Leerzeichen lschen
	   (setq strvalue (delLeadingSpaces strvalue))
	   ;(princ (strcat "\n" sTagName ": = [" strValue "]"))
	   (if (= strvalue "") (setq strvalue nil))
	   (setq index (length lattrib)) ; Schleife beenden
	 )  
       )
       (setq index (1+ index))
    ); ende while alle Attribute des SSM-Objektes durchlaufen 
  
  strvalue  
)
;####################################################################################
;;   delLeadingSpaces 								    ;
;;     Funktion gibt den bergebenen Sring ohne fhrende Leerzeichen zurck         ;
;;     Der original String wird nicht verndert                                     ;
;;                                                                                  ;
;;   Parameter:  string  => Zu prfender String   				    ;
;;                                                                                  ;
;;   Rckgabewert: Der String ohne fhrende Leerzeichen                             ;
;; ##################################################################################
(defun delLeadingSpaces (string / len nStartPos i string retStr)
    
    (setq retStr "")
    (setq len (strlen string))
    (setq nStartPos len)
    (setq i 1)
    (while (<= i len)
    	(if (/= (substr string i 1) " ")
	    (progn
		(setq nStartPos i);Startposition des ersten nicht leeren Zeichens
	    	(setq i (1+ len));Ende Schleife
	    )
	    (setq i (1+ i))
	)
    )
    (if (< 0 len)
	(progn
	    (setq retStr (substr string nStartPos len))
	    (if (= retStr " ")(setq retStr ""))
	)
   )	
   retStr 
)

